@@ -58,11 +58,8 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #define MAGPI_URL       "https://store.rpipress.cc/collections/the-magpi-essentials"
 #define BOOKS_URL       "https://store.rpipress.cc/collections/latest-bookazines"
-#define HACKSPACE_URL   "https://store.rpipress.cc/collections/hackspace-magazine"
-#define WIREFRAME_URL   "https://store.rpipress.cc/collections/wireframe"
-#define CUSTOMPC_URL    "https://store.rpipress.cc/collections/custom-pc-magazine"
 
-#define CATALOGUE_URL   "https://magpi.raspberrypi.org/bookshelf.xml"
+#define CATALOGUE_URL   "https://magpi.raspberrypi.com/bookshelf.xml"
 #define CACHE_PATH      "/.cache/bookshelf/"
 #define PDF_PATH        "/Bookshelf/"
 
@@ -87,10 +84,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #define CAT_MAGPI           0
 #define CAT_BOOKS           1
-#define CAT_HSPACE          2
-#define CAT_WFRAME          3
-#define CAT_CUSTPC          4
-#define NUM_CATS            5
+#define NUM_CATS            2
 
 /* Termination function arguments */
 
@@ -156,11 +150,11 @@ static char *get_local_path (char *path, const char *dir);
 static void create_dir (char *dir);
 static unsigned long int get_val (char *cmd);
 static char *get_string (char *cmd);
-static double free_space (void);
+static curl_off_t free_space (void);
 static void start_curl_download (char *url, char *file, void (*end_fn)(tf_status success));
 static gboolean curl_poll (gpointer data);
 static void finish_curl_download (void);
-static int progress_func (GtkWidget *bar, double t, double d, double ultotal, double ulnow);
+static int progress_func (GtkWidget *bar, curl_off_t t, curl_off_t d, curl_off_t ultotal, curl_off_t ulnow);
 static GdkPixbuf *get_cover (const char *filename);
 static void update_cover_entry (char *lpath, int dl, gboolean new);
 static gboolean find_cover_for_item (gpointer data);
@@ -207,6 +201,19 @@ static char *get_local_path (char *path, const char *dir)
     return rpath;
 }
 
+/* get_system_path - creates a string with path to file in package data dir */
+
+static char *get_system_path (char *path)
+{
+    gchar *basename, *rpath;
+    basename = g_path_get_basename (path);
+    rpath = strchr (basename, '?');
+    if (rpath) *rpath = 0;
+    rpath = g_strdup_printf ("%s/%s", PACKAGE_DATA_DIR, basename);
+    g_free (basename);
+    return rpath;
+}
+
 /* create dir - create a directory if it doesn't exist */
 
 static void create_dir (char *dir)
@@ -244,7 +251,7 @@ static unsigned long int get_val (char *cmd)
     }
 }
 
-/* get_val - call a system command and return the first string in the output */
+/* get_string - call a system command and return the first string in the output */
 
 static char *get_string (char *cmd)
 {
@@ -270,11 +277,11 @@ static char *get_string (char *cmd)
 
 /* free_space - find free space on filesystem */
 
-static double free_space (void)
+static curl_off_t free_space (void)
 {
     char *cmd;
     unsigned long fs;
-    double ffs = 1024.0;
+    curl_off_t ffs = 1024;
     cmd = g_strdup_printf ("df --output=avail %s%s | tail -n 1", g_get_home_dir (), PDF_PATH);
     fs = get_val (cmd);
     g_free (cmd);
@@ -310,7 +317,7 @@ static void start_curl_download (char *url, char *file, void (*end_fn)(tf_status
     curl_easy_setopt (http_handle, CURLOPT_USERAGENT, USER_AGENT);
     curl_easy_setopt (http_handle, CURLOPT_WRITEDATA, outfile);
     curl_easy_setopt (http_handle, CURLOPT_NOPROGRESS, 0L);
-    curl_easy_setopt (http_handle, CURLOPT_PROGRESSFUNCTION, progress_func);
+    curl_easy_setopt (http_handle, CURLOPT_XFERINFOFUNCTION, progress_func);
 
     curl_multi_add_handle (multi_handle, http_handle);
     if (curl_multi_perform (multi_handle, &still_running) == CURLM_OK && still_running)
@@ -362,9 +369,11 @@ static void finish_curl_download (void)
     term_fn (downstat);
 }
 
-static int progress_func (GtkWidget *bar, double t, double d, double ultotal, double ulnow)
+static int progress_func (GtkWidget *bar, curl_off_t t, curl_off_t d, curl_off_t ultotal, curl_off_t ulnow)
 {
-    double prog = d / t;
+    double prog = d;
+    prog /= t;
+
     if (cancelled)
     {
         downstat = CANCELLED;
@@ -517,8 +526,18 @@ static void pdf_selected (void)
     gchar *ppath, *plpath;
 
     gtk_tree_model_get (GTK_TREE_MODEL (items), &selitem, ITEM_PDFPATH, &ppath, -1);
-    plpath = get_local_path (ppath, PDF_PATH);
 
+    plpath = get_system_path (ppath);
+    if (access (plpath, F_OK) != -1)
+    {
+        open_pdf (plpath);
+        g_free (plpath);
+        g_free (ppath);
+        return;
+    }
+    g_free (plpath);
+
+    plpath = get_local_path (ppath, PDF_PATH);
     if (access (plpath, F_OK) == -1)
     {
         message (_("Downloading - please wait..."), FALSE);
@@ -597,38 +616,38 @@ static void get_pending_pdf (void)
 #define N_REMAPS 32
 
 const char *titlemap[N_REMAPS][2] = {
-    "Build Your Own First-Person Shooter in Unity",     "Build a First-Person Shooter",
-    "Book of Making Volume 2",                          "HackSpace Book of Making Volume 2",
-    "Code the Classics – Volume 1",                     "Code the Classics Volume 1",
-    "Get Started with Arduino",                         "Get Started with Arduino",
-    "Projects Book 5",                                  "Raspberry Pi Projects Book 5",
-    "Retro Gaming with Raspberry Pi",                   "Retro Gaming with Raspberry Pi",
-    "Get Started with Raspberry Pi",                    NULL,
-    "Raspberry Pi Beginner's Guide v3",                 "Raspberry Pi Beginner's Guide",
-    "Beginner's Guide v2",                              NULL,
-    "Wearable Tech Projects",                           "Wearable Tech Projects",
-    "C &amp; GUI Programming",                          "C &amp; GUI Programming",
-    "Command Line 2",                                   "Essentials - Conquer the Command Line",
-    "Book of Scratch",                                  "Code Club Book of Scratch",
-    "Beginner's Guide",                                 NULL,
-    "Book of Making Volume 1",                          "HackSpace Book of Making Volume 1",
-    "Projects Book 4",                                  "Raspberry Pi Projects Book 4",
-    "Annual 2018",                                      "Raspberry Pi Annual 2018",
-    "Beginner's Book 1",                                NULL,
-    "Projects Book 3",                                  "Raspberry Pi Projects Book 3",
-    "AIY Voice Essentials",                             "Essentials - AIY Voice Projects",
-    "Camera Essentials",                                "Essentials - Camera Module Guide",
-    "Projects Book 2",                                  "Raspberry Pi Projects Book 2",
-    "Learn C Essentials",                               "Essentials - Learn to Code with C",
-    "GPIO Zero Essentials",                             "Essentials - GPIO Zero Electronics",
-    "Minecraft Essentials",                             "Essentials - Making with Minecraft",
-    "Scratch Essentials",                               "Essentials - Learn to Code with Scratch",
-    "Sonic Pi Essentials",                              "Essentials - Code Music with Sonic Pi",
-    "Sense HAT Essentials",                             "Essentials - Sense HAT Experiments",
-    "Make Games",                                       "Essentials - Make Games with Python",
-    "Projects Book",                                    "Raspberry Pi Projects Book 1",
-    "Command Line",                                     NULL,
-    "MagPi SE 1",                                       NULL
+    {"Build Your Own First-Person Shooter in Unity",     "Build a First-Person Shooter"},
+    {"Book of Making Volume 2",                          "HackSpace Book of Making Volume 2"},
+    {"Code the Classics – Volume 1",                     "Code the Classics Volume 1"},
+    {"Get Started with Arduino",                         "Get Started with Arduino"},
+    {"Projects Book 5",                                  "Raspberry Pi Projects Book 5"},
+    {"Retro Gaming with Raspberry Pi",                   "Retro Gaming with Raspberry Pi"},
+    {"Get Started with Raspberry Pi",                    NULL},
+    {"Raspberry Pi Beginner's Guide v3",                 "Raspberry Pi Beginner's Guide"},
+    {"Beginner's Guide v2",                              NULL},
+    {"Wearable Tech Projects",                           "Wearable Tech Projects"},
+    {"C &amp; GUI Programming",                          "C &amp; GUI Programming"},
+    {"Command Line 2",                                   "Essentials - Conquer the Command Line"},
+    {"Book of Scratch",                                  "Code Club Book of Scratch"},
+    {"Beginner's Guide",                                 NULL},
+    {"Book of Making Volume 1",                          "HackSpace Book of Making Volume 1"},
+    {"Projects Book 4",                                  "Raspberry Pi Projects Book 4"},
+    {"Annual 2018",                                      "Raspberry Pi Annual 2018"},
+    {"Beginner's Book 1",                                NULL},
+    {"Projects Book 3",                                  "Raspberry Pi Projects Book 3"},
+    {"AIY Voice Essentials",                             "Essentials - AIY Voice Projects"},
+    {"Camera Essentials",                                "Essentials - Camera Module Guide"},
+    {"Projects Book 2",                                  "Raspberry Pi Projects Book 2"},
+    {"Learn C Essentials",                               "Essentials - Learn to Code with C"},
+    {"GPIO Zero Essentials",                             "Essentials - GPIO Zero Electronics"},
+    {"Minecraft Essentials",                             "Essentials - Making with Minecraft"},
+    {"Scratch Essentials",                               "Essentials - Learn to Code with Scratch"},
+    {"Sonic Pi Essentials",                              "Essentials - Code Music with Sonic Pi"},
+    {"Sense HAT Essentials",                             "Essentials - Sense HAT Experiments"},
+    {"Make Games",                                       "Essentials - Make Games with Python"},
+    {"Projects Book",                                    "Raspberry Pi Projects Book 1"},
+    {"Command Line",                                     NULL},
+    {"MagPi SE 1",                                       NULL}
 };
 
 static void remap_title (char **title)
@@ -674,7 +693,7 @@ static void get_param (char *linebuf, char *name, char *lang, char **dest)
     if (lang) search = g_strdup_printf ("<%s LANG=\"%s\">", name, lang);
     else search = g_strdup_printf ("<%s>", name);
     
-    if (p1 = strstr (linebuf, search))
+    if ((p1 = strstr (linebuf, search)))
     {
         p1 += strlen (search);
         p2 = strchr (p1, '<');
@@ -737,7 +756,11 @@ static int read_data_file (char *path)
                         downloaded = FALSE;
                         if (pdfpath)
                         {
-                            gchar *lpath = get_local_path (pdfpath, PDF_PATH);
+                            char *lpath;
+                            lpath = get_system_path (pdfpath);
+                            if (access (lpath, F_OK) != -1) downloaded = TRUE;
+                            g_free (lpath);
+                            lpath = get_local_path (pdfpath, PDF_PATH);
                             if (access (lpath, F_OK) != -1) downloaded = TRUE;
                             g_free (lpath);
                         }
@@ -769,9 +792,6 @@ static int read_data_file (char *path)
             {
                 if (strstr (linebuf, "<MAGPI>")) category = CAT_MAGPI;
                 if (strstr (linebuf, "<BOOKS>")) category = CAT_BOOKS;
-                if (strstr (linebuf, "<HACKSPACE>")) category = CAT_HSPACE;
-                if (strstr (linebuf, "<WIREFRAME>")) category = CAT_WFRAME;
-                if (strstr (linebuf, "<CUSTOMPC>")) category = CAT_CUSTPC;
                 if (strstr (linebuf, "<ITEM>")) in_item = TRUE;
             }
         }
@@ -804,7 +824,7 @@ static gboolean match_category (GtkTreeModel *model, GtkTreeIter *iter, gpointer
     int cat;
 
     gtk_tree_model_get (model, iter, ITEM_CATEGORY, &cat, -1);
-    return (cat == (int) data);
+    return (cat == (long) data);
 }
 
 
@@ -1023,12 +1043,6 @@ static void web_link (GtkButton* btn, gpointer ptr)
                         exit (0);
             case 1 :    execl ("/usr/bin/xdg-open", "xdg-open", BOOKS_URL, NULL);
                         exit (0);
-            case 2 :    execl ("/usr/bin/xdg-open", "xdg-open", HACKSPACE_URL, NULL);
-                        exit (0);
-            case 3 :    execl ("/usr/bin/xdg-open", "xdg-open", WIREFRAME_URL, NULL);
-                        exit (0);
-            case 4 :    execl ("/usr/bin/xdg-open", "xdg-open", CUSTOMPC_URL, NULL);
-                        exit (0);
         }
     }
 }
@@ -1064,7 +1078,7 @@ int main (int argc, char *argv[])
     GtkBuilder *builder;
     GtkCellLayout *layout;
     GtkCellRenderer *renderer;
-    int i;
+    long i;
 
 #ifdef ENABLE_NLS
     setlocale (LC_ALL, "");
@@ -1101,9 +1115,6 @@ int main (int argc, char *argv[])
     main_dlg = (GtkWidget *) gtk_builder_get_object (builder, "main_window");
     item_ivs[CAT_MAGPI] = (GtkWidget *) gtk_builder_get_object (builder, "iconview_magpi");
     item_ivs[CAT_BOOKS] = (GtkWidget *) gtk_builder_get_object (builder, "iconview_books");
-    item_ivs[CAT_HSPACE] = (GtkWidget *) gtk_builder_get_object (builder, "iconview_hack");
-    item_ivs[CAT_WFRAME] = (GtkWidget *) gtk_builder_get_object (builder, "iconview_wire");
-    item_ivs[CAT_CUSTPC] = (GtkWidget *) gtk_builder_get_object (builder, "iconview_custpc");
     close_btn = (GtkWidget *) gtk_builder_get_object (builder, "button_ok");
     web_btn = (GtkWidget *) gtk_builder_get_object (builder, "button_web");
     items_nb = (GtkWidget *) gtk_builder_get_object (builder, "notebook1");
